==> lxqt-config_1.3.0.orig.tar.xz: lxqt-config-1.3.0/lxqt-config-monitor/translations/lxqt-config-monitor_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Brze opcije</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Prošireni prikaz</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Sjedinjeni prikaz</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Samo prva</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Samo druga</translation>
    </message>
</context>
<context>
    <name>LoadSettings</name>
    <message>
        <location filename="../loadsettings.cpp" line="98"/>
        <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
        <translation>Primijenjene su standardne postavke monitora. Ako želiš promijeniti postavke monitora, koristi lxqt-config-monitor.</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Postavke monitora</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Spremljene postavke</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>Primijeni</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="62"/>
        <source>None</source>
        <translation>Ništa</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="65"/>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="68"/>
        <source>Inverted</source>
        <translation>Preokrenuto</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="71"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <location filename="../managesavedsettings.cpp" line="76"/>
        <source>True</source>
        <translation>Točno</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <location filename="../managesavedsettings.cpp" line="76"/>
        <source>False</source>
        <translation>Netočno</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="136"/>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="136"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Zadrži monitore priključenima</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Postavke monitora</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="70"/>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="106"/>
        <source>Fast Menu</source>
        <translation>Brzi izbornik</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="110"/>
        <source>Set position</source>
        <translation>Odredi mjesto</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="229"/>
        <source>Advanced settings</source>
        <translation>Napredne postavke</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Postava</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>Razlučivost:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>Aktiviraj ovaj ekran</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>Ovo je moj glavni ekran</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>Ovaj ekran proširuje jedan drugi ekran</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Napredno</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>Stopa osvježavanja:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>Okretanje:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Podaci ekrana</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="129"/>
        <source>Name: %1
</source>
        <translation>Ime: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="130"/>
        <source>Vendor: %1
</source>
        <translation>Proizvođač: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="131"/>
        <source>Serial: %1
</source>
        <translation>Serijski: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="132"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Veličina ekrana: %1 cm × %2 cm
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="133"/>
        <source>Serial number: %1
</source>
        <translation>Serijski broj: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="134"/>
        <source>EISA device ID: %1
</source>
        <translation>EISA ID uređaja: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="154"/>
        <source>None</source>
        <translation>Ništa</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="155"/>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="156"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="157"/>
        <source>Inverted</source>
        <translation>Preokrenuto</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="245"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Upravljaj spremljenim postavkama</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Postavke su promijenjene</translation>
    </message>
    <message>
        <location filename="../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Jesu li trenutačne postavke u redu?</translation>
    </message>
    <message numerus="yes">
        <location filename="../timeoutdialog.cpp" line="63"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>preostaje %n sekunda</numerusform>
            <numerusform>preostaju %n sekunde</numerusform>
            <numerusform>preostaje %n sekundi</numerusform>
        </translation>
    </message>
</context>
</TS>

==> lxqt-config-2.2.0.tar.xz: lxqt-config-2.2.0/lxqt-config-monitor/translations/lxqt-config-monitor_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Brze opcije</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Prošireni prikaz</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Sjedinjeni prikaz</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Samo prva</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Samo druga</translation>
    </message>
</context>
<context>
    <name>LoadSettings</name>
    <message>
        <location filename="../loadsettings.cpp" line="97"/>
        <source>Default monitor settings applied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="98"/>
        <source>Adjust your screens with LXQt Monitor Settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="107"/>
        <source>lxqt-config-monitor: Settings applied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="109"/>
        <source>lxqt-config-monitor: Settings not applied.
If this is a Wayland compositor, you could try kanshi to configure your monitor(s).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Postavke monitora</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Spremljene postavke</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="45"/>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="52"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="66"/>
        <source>None</source>
        <translation>Ništa</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="69"/>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="72"/>
        <source>Inverted</source>
        <translation>Preokrenuto</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="79"/>
        <location filename="../managesavedsettings.cpp" line="80"/>
        <source>True</source>
        <translation>Točno</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="79"/>
        <location filename="../managesavedsettings.cpp" line="80"/>
        <source>False</source>
        <translation>Netočno</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="139"/>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="139"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="172"/>
        <source>Settings Activation Failed</source>
        <translation>Aktivacija postavki nije uspjela</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="173"/>
        <source>Selected settings cannot be applied with currently active monitors.

Please choose from the highlighted configurations.</source>
        <translation>Odabrane postavke se ne mogu primijeniti na trenutačno aktivne monitore.

Odaberi jednu od istaknutih konfiguracija.</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Zadrži monitore priključenima</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Postavke monitora</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="70"/>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="62"/>
        <source>Platform Unsupported</source>
        <translation>Platforma nije podržana</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="63"/>
        <source>LXQt monitor settings are currently unsupported under this wayland compositor.

You can configure your monitor(s) with kanshi.</source>
        <translation>LXQt postavke monitora trenutačno nisu podržane u ovom wayland sastavljaču.

Svoje monitore možeš konfigurirati s kanshi.</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="118"/>
        <source>Fast Menu</source>
        <translation>Brzi izbornik</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="122"/>
        <source>Set position</source>
        <translation>Odredi mjesto</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="241"/>
        <source>Advanced settings</source>
        <translation>Napredne postavke</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Postava</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="64"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="80"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="36"/>
        <source>Resolution:</source>
        <translation>Razlučivost:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="27"/>
        <source>Enable this display</source>
        <translation>Aktiviraj ovaj ekran</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="49"/>
        <source>This is my primary display</source>
        <translation>Ovo je moj glavni ekran</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="54"/>
        <source>This screen extends another display</source>
        <translation>Ovaj ekran proširuje jedan drugi ekran</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Napredno</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="143"/>
        <source>Refresh rate:</source>
        <translation>Stopa osvježavanja:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="133"/>
        <source>Rotation:</source>
        <translation>Okretanje:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Podaci ekrana</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="129"/>
        <source>Name: %1
</source>
        <translation>Ime: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="130"/>
        <source>Vendor: %1
</source>
        <translation>Proizvođač: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="131"/>
        <source>Serial: %1
</source>
        <translation>Serijski: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="132"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Veličina ekrana: %1 cm × %2 cm
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="133"/>
        <source>Serial number: %1
</source>
        <translation>Serijski broj: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="134"/>
        <source>EISA device ID: %1
</source>
        <translation>EISA ID uređaja: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="155"/>
        <source>None</source>
        <translation>Ništa</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="156"/>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="157"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="158"/>
        <source>Inverted</source>
        <translation>Preokrenuto</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="248"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Upravljaj spremljenim postavkama</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Postavke su promijenjene</translation>
    </message>
    <message>
        <location filename="../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Jesu li trenutačne postavke u redu?</translation>
    </message>
    <message numerus="yes">
        <location filename="../timeoutdialog.cpp" line="63"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>preostaje %n sekunda</numerusform>
            <numerusform>preostaju %n sekunde</numerusform>
            <numerusform>preostaje %n sekundi</numerusform>
        </translation>
    </message>
</context>
</TS>
